@@ -1,3 +1,7 @@
+"""
+It answers "pong" if receives "ping"
+"""
+
 import logging
 import argparse
 
@@ -7,7 +11,7 @@ from utils import setup_logging
 
 
 if __name__ == '__main__':
-    setup_logging(level=logging.DEBUG)
+    setup_logging(level=logging.INFO)
 
     parser = argparse.ArgumentParser()
     parser.add_argument('api_id', help='API id')  # https://my.telegram.org/apps
